@@ -1,13 +1,20 @@
 use core::iter::Iterator;
 
 #[cfg(feature = "with-chrono")]
-use chrono::{DateTime, TimeZone};
+use chrono::{DateTime, NaiveDateTime, TimeZone};
 use hour::Hour;
 use weekday::Weekday;
 
 #[derive(PartialEq, Eq, Hash, PartialOrd, Ord, Debug, Copy, Clone)]
 pub struct WeekdayAndHour(pub Weekday, pub Hour);
 
+#[cfg(feature = "with-chrono")]
+impl From<NaiveDateTime> for WeekdayAndHour {
+    fn from(dt: NaiveDateTime) -> Self {
+        Self(Weekday::from(dt), Hour::from(dt))
+    }
+}
+
 #[cfg(feature = "with-chrono")]
 impl<Tz: TimeZone> From<DateTime<Tz>> for WeekdayAndHour {
     fn from(dt: DateTime<Tz>) -> Self {
@@ -50,7 +57,23 @@ mod tests {
     use super::*;
 
     #[test]
-    fn simple() {
+    fn test_iter() {
         assert_eq!(WeekdayAndHourIterator::new().into_iter().count(), 7 * 24);
     }
+
+    #[cfg(feature = "with-chrono")]
+    #[test]
+    fn test_from_chrono() {
+        use chrono::Utc;
+
+        assert_eq!(
+            WeekdayAndHour::from("2021-08-01T00:00:00".parse::<NaiveDateTime>().unwrap()),
+            WeekdayAndHour(Weekday::Sun, Hour::C0)
+        );
+
+        assert_eq!(
+            WeekdayAndHour::from("2021-08-01T00:00:00Z".parse::<DateTime<Utc>>().unwrap()),
+            WeekdayAndHour(Weekday::Sun, Hour::C0)
+        );
+    }
 }
